from setuptools import setup, find_packages

setup(
    name="tab-synthgen",
    version="0.1.0",
    author="Priyesh Dave",
    author_email="genaiwork6@gmail.com",
    description="A private package bundling RCTGAN for tabular synthetic data generation.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/PriyeshDave/SynthGen",
    packages=find_packages(),
    install_requires=[
        "numpy",
        "pandas",
        "torch",
        "rdt",
        "sdv",
        # Add all other dependencies from RCTGAN
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.7",
)
